@@ -18,6 +18,8 @@ class KongAuth(BaseAuth):
         '''
         if not isinstance(current_app.session_interface,RedisSessionInterface):
             raise Exception('请在app/__init__.py的create_app_swagger方法中增加下列代码：\n app.session_interface = RedisSessionInterface(app, rds)')
+        # redis 中session的过期时间，为0时，为第一次设定的时间
+        session_expiration_time = current_app.config.get('SESSION_EXPIRATION_TIME', 0)
         if current_app.config.get('DEVELOPMENT', False):
             g.user_name = current_app.config.get('LOGIN_USER_NAME')  # 'user_dev'
             g.user_id = current_app.config.get('LOGIN_USER_ID')
@@ -30,12 +32,14 @@ class KongAuth(BaseAuth):
                                   type=session.get('type', 'appuser')
                                   )
             g.jwt = session.sid
+            # 只有session 認證才需要設定這個redis的有效期
+            session.temp_expiration_time = session_expiration_time
             session.update({'uid':g.current_user.uid,'uname':g.current_user.uname,
                             'systemuser':g.current_user.systemuser,
                             'manageuser':g.current_user.manageuser,
                             'manageuserid':g.current_user.manageuserid})
             return
-        # 通过了jwt 认证的 api 一定会回传username和userid，否则视为kong的认证不成功
+        # 通过了jwt 或 key 认证的 api 一定会回传username和userid，否则视为kong的认证不成功
         g.user_name = request.headers.get('X-Consumer-Username')
         g.user_id = request.headers.get('X-Consumer-Custom-Id')
         # key auth 或jwt auth
@@ -56,10 +60,14 @@ class KongAuth(BaseAuth):
                 g.user_name = None
                 g.user_id = None
                 return
+            # 只有session 認證才需要設定這個redis的有效期
+            session.temp_expiration_time = session_expiration_time
         elif session and session.sid!=g.jwt:
             # 如果有传jwt ，就使用jwt的，cookie中的session可能是上一次的，需刷新为jwt的
             session.sid = g.jwt
             mysession = current_app.session_interface.get_session(g.jwt)
+            # 只有session 認證才需要設定這個redis的有效期
+            session.temp_expiration_time = session_expiration_time
             session.update(dict(mysession))
         if not session:
             # 当非session认证时，还需保存session，保证app中的代码的兼容性
@@ -75,6 +83,8 @@ class KongAuth(BaseAuth):
                             'manageuserid':'',
                             'type':'appuser'}))
             else:
+                # 只有session 認證才需要設定這個redis的有效期
+                # session.temp_expiration_time = session_expiration_time
                 session.update(dict(mysession))
         g.current_user = User(uid=session.get('uid'),
                               uname=session.get('uname'),
